<?php
/**
 * API de vérification : vérification qu'une chaîne puisse décrire un tableau de data pour une saisies
 *
 * @plugin     saisies
 */

// Sécurité
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}
/**
 * Vérifier qu'une saisie est sous forme d'une chaine transformable en tableau de data
 * C'est-à-dire de la forme cle|valeur
 * Et ce en autorisant les sous-groupes (sauf si demande contraire)
 * Mais en refusant les clés construite automatiquement pour des lignes sans pipe.
 * On en profite pour vérifier qu'il n'y pas de clé en double.
 * De plus les trim() pertubent les choses.
 * @param string $valeur
 *   La valeur à vérifier.
 * @param $options
 *	 interdire_sous_groupes => True|False
 * @return string
 *   Retourne une chaine vide si c'est valide, sinon une chaine expliquant l'erreur.
 */
function verifier_saisies_option_data_dist($valeur, $options = array()) {
	include_spip('inc/saisies');
	$tableau = saisies_chaine2tableau($valeur);
	$tableau_plat = saisies_aplatir_tableau($tableau);

	// Manquent-t-il des clés explicites ?
	foreach ($tableau_plat as $cle => $entree) {
		if (gettype($cle) === 'integer') {
			if (!preg_match("#^$cle\|#m", $valeur)) {//Permettre tout de même la syntaxe 1|Toto
				return _T('saisies:verifier_saisies_option_data_cle_manquante');
			}
		}
	}
	// Les sous groupes sont-ils interdits?
	if (
			isset($options['interdire_sous_groupes'])
			and $options['interdire_sous_groupes']
			and $tableau_plat !== $tableau) {
			return _T('saisies:verifier_saisies_option_data_sous_groupes_interdits');
	}
	// Y-a-il des clés en double ?
	preg_match_all('#^(.*)\|#m',$valeur,$les_cles);
	$les_cles = $les_cles[1];
	if ($les_cles != array_unique($les_cles)) {
			return _T('saisies:verifier_saisies_option_data_cles_doubles');
	}
	// Et sinon, c'est que cela passe
	return '';
}
